<?php
/**
 * Dofus_Error_Handler.class.php
 * 
 * Class for handling any errors
 * 
 * @author Jim Wordelman <j.wordelman@quad341.com>
 * @package Dofus
 * @subpackage Controller
 */

require_once "Dofus_View.class.php";

class Dofus_Error_Handler {
	/**
	 * Displays the error to the user (params: none)
	 *
	 */
	const DOFUS_ERROR_HANDLER_DISPLAY = 0;
	/**
	 * Logs the error to a file. (params: array(0=>filename(string),1=>email also?(bool),2=>email address(string))
	 *
	 */
	const DOFUS_ERROR_HANDLER_LOG = 1;
	/**
	 * Emails the error to the supplied person (params: string email address)
	 *
	 */
	const DOFUS_ERROR_HANDLER_EMAIL = 2;
	/**
	 * Does nothing with the error. Only should be used if PHP error logging handles the error. (params: none)
	 *
	 */
	const DOFUS_ERROR_HANDLER_SUPRESS = 3;
	
	/**
	 * The view handler to attempt to display the error page
	 *
	 * @var Dofus_View
	 */
	protected $view = false;
	/**
	 * Constructor that initiates the view and can also handle the error directly
	 *
	 * @param string $error The error message
	 * @param int $error_method The method of handling the error (use constants of this class)
	 * @param string|array[optional] $error_param The parameters for the method
	 */
	public function __construct($error=null,$error_method=null,$error_param=null){
		$this->view = new Dofus_View();
		if($error==null){
			switch($error_method){
				case self::DOFUS_ERROR_HANDLER_DISPLAY:
					$this->display($error);
					break;
				case self::DOFUS_ERROR_HANDLER_EMAIL:
					$this->emailError($error,$error_param);
					break;
				case self::DOFUS_ERROR_HANDLER_LOG:
					$this->logError($error,$error_param);
					break;
				default: // supresses the error. not exactly useful
					$this->display();
			}
		}
	}
	/**
	 * Displays the error page with the error is supplied
	 *
	 * @param string[optional] $error The error to display
	 */
	public function display($error=null){
		$this->view->error = $error;
		try{
			$this->view->render('errorhandler.view.php');
		} catch (Exception $e){
			if($error==null)
				die('An error has occurred. It is currently being handled. Please check back later');
			else
				die('The following error has occurred: '.$error);
		}
	}
	/**
	 * Emails the error and then displays the error page without the error showing
	 *
	 * @param string $error The error to email
	 * @param string $email_address The email address to send the error to
	 */
	public function emailError($error,$email_address){
		$host = $_SERVER['HTTP_HOST'];
		mail($email_address,'Error occurred with Dofus Commerce',"The following error has occurred: \r\n".$error."\r\nPlease correct this error.",'From: dofus_commerce@'.$host);
		$this->display();
	}
	/**
	 * Logs the error to a file (preserving past entries).
	 * 
	 * Parameters is a numerical array as follows: 0=>(string) filename in which to log the error,
	 * 1=>(bool) Whether or not to also email the error, 2=>(string[optional]) the email address to which to send the error.
	 *
	 * @param string $error The error to log
	 * @param array $params The array of parameters
	 */
	public function logError($error,$params){
		// $params[0] is string filename.
		// $params[1] is bool Also email
		// $params[2] is string email if above is true
		$contents = file_get_contents($params[0]);
		$timestamp = date('Y-M-D\\TH:m:s',time());
		$contents .= "\r\n" . $timestamp . " - " . $error;
		file_put_contents($params[0],$contents);
		if($params[1])
			$this->emailError($error,$params[2]);
		else
			$this->display();
	}
}
?>