<?php
/**
 * Dofus_View.class.php
 * 
 * Class for rendering the views (pages) of the application
 * 
 * @author Jim Wordelman <j.wordelman@quad341.com>
 * @package Dofus
 * @subpackage Controller
 */
/**
 * Exception class used when template is not found
 * 
 * @package Dofus
 * @subpackage Exception
 *
 */
class Dofus_View_No_Template_Exception extends Exception{}
/**
 * Class for rendering views
 *
 */
class Dofus_View{
	/**
	 * The standard directory for views
	 * 
	 * This is defined from where the implementations are (usually /)
	 *
	 */
	const DOFUS_VIEW_DIRECTORY = "views/";
	/**
	 * The location for the modules that views may use
	 * 
	 * Usually this directory is located within the views directory specified above
	 *
	 */
	const DOFUS_VIEW_MODULE_DIR = "views/modules/";
	/**
	 * The directory in which to look by default for the view
	 *
	 * @var string
	 */
	protected $view_dir = false;
	/**
	 * An array of the steps to the current location
	 *
	 * @var array
	 */
	protected $breadcrumb = false;
	/**
	 * Constructor function that sets the default directory
	 *
	 * @param string[optional] $dir The default view directory. Defaults to current directory
	 */
	public function __construct($dir=Dofus_View::DOFUS_VIEW_DIRECTORY){
		$this->SetViewDir($dir);
	}
	/**
	 * Function to create the view specified
	 *
	 * @param string $filename The view to render
	 * @throws PPT_View_No_Template_Exception
	 */
	public function render($filename){
		if($this->view_dir!==false && file_exists($this->view_dir.$filename)) include $this->view_dir.$filename;
		elseif(file_exists($filename)) include $filename;
		else throw new Dofus_View_No_Template_Exception($filename . " not found. Check template directory.");
	}
	/**
	 * Creates the specified view and returns it as a string
	 *
	 * @param string $filename The name of the view
	 * @return string
	 */
	public function cacheRender($filename){
		ob_start();
		$this->render($filename);
		$contents = ob_get_contents();
		ob_clean();
		return $contents;
	}
	/**
	 * Sets the default view (template) directory
	 *
	 * @param string[optional] $dir The default directory
	 */
	public function SetViewDir($dir=Dofus_View::DOFUS_VIEW_DIRECTORY){
		$dir=str_replace('\\','/',$dir);
		if(substr($dir,strlen($dir)-2)!="/")
			$dir = $dir . "/";
		$this->view_dir = $dir;
	}
	/**
	 * Sets the default template directory. Alias for SetViewDir
	 *
	 * @param string[optional] $dir The default directory
	 */
	public function SetTemplateDir($dir=Dofus_View::DOFUS_VIEW_DIRECTORY){
		$this->SetViewDir($dir);
	}
	/**
	 * Returns the current default template directory
	 *
	 * @return string
	 */
	public function GetTemplateDir(){
		return $this->view_dir;
	}
	/**
	 * Returns the current default template directory
	 *
	 * @return string
	 */
	public function GetViewDir(){
		return $this->view_dir;
	}
	/**
	 * Adds a link to the breadcrumb array
	 *
	 * @param string $title The title (display text) of the link
	 * @param string $link The URL of the link
	 */
	public function addCrumb($title,$link){
		$this->breadcrumb[] = array('title'=>$title,'link'=>$link);
	}
	/**
	 * Returns the current breadcrumb array
	 *
	 * @return array
	 */
	public function getCrumbs(){
		return $this->breadcrumb;
	}
}
?>